﻿using System;
using System.Linq;
using System.Security.Claims;

namespace NetsBrokerIntegration.NetCore.Extensions
{
    public static class UserExtensions
    {
        public static string GetAcrClaimValue(this ClaimsPrincipal user)
        {
            var acrClaim = user.Claims.SingleOrDefault(c => c.Type == "acr").Value;
            return string.IsNullOrEmpty(acrClaim)
                ? null
                : acrClaim;
        }

        public static bool CanStepUp(this ClaimsPrincipal user)
        {
            var acrClaim = GetAcrClaimValue(user);
            return acrClaim == AcrConstants.MitIdDemoOneFactor || acrClaim == AcrConstants.MitIdLow;
        }

        public static string GetStepUpTwoFactorClaim(this ClaimsPrincipal user)
        {
            return GetAcrClaimValue(user) switch
            {
                AcrConstants.MitIdDemoOneFactor => AcrConstants.MitIdDemoTwoFactor,
                AcrConstants.MitIdLow => AcrConstants.MitIdSubstantial,
                _ => throw new NotSupportedException("Acr claim value is not supported")
            };
        }
    }
}
